@@ -2,7 +2,7 @@ import logging as logging_module
 import os
 import platform
 import sys
-import subprocess
+import subprocess, signal
 import time
 from whatap import build
 from whatap.util.date_util import DateUtil
@@ -289,39 +289,10 @@ def agent():
     if write_file(home, home.lower(), whatap_home):
         os.environ['WHATAP_HOME'] = whatap_home
         
-        t = threading.Thread(target=go)
-        t.setDaemon(True)
-        t.start()
+        # t = threading.Thread(target=go)
+        # t.setDaemon(True)
+        # t.start()
         config(home)
-        #startWhatapThread()
-
-def startWhatapThread():
-    def __whatap_jobs():
-        from whatap.conf.configure import Configure as conf
-        from whatap.net.udp_session import UdpSession
-        UdpSession.read_timeout = conf.session_read_timeout
-        UdpSession.udp()
-
-        def __udp_recv():
-            UdpSession.get()
-
-        def __config_load():
-            now = time.time()
-            if now - conf.last_loaded > conf.init_load_interval / 1000:
-                conf.init(False)
-
-        while True:
-            for job in (__udp_recv, __config_load):
-                try:
-                    job()
-                    time.sleep(0)
-                except Exception as e:
-                    logging.debug(e, extra={'id': 'WA914'}, exc_info=True)
-                    time.sleep(0.05)
-
-    t = threading.Thread(target=__whatap_jobs)
-    t.setDaemon(True)
-    t.start()
 
 ARCH = {
     'x86_64': 'amd64',
@@ -334,22 +305,19 @@ ARCH = {
 AGENT_NAME = 'whatap_python'
 
 
-def go(batch=False):
-    os.environ['WHATAP_VERSION'] = build.version
-    
-    os.environ['whatap.start'] = str(DateUtil.now())
-    
-    os.environ['python.uptime'] = str(DateUtil.datetime())
-    os.environ['python.version'] = sys.version
-    os.environ['python.tzname'] = time.tzname[0]
 
-    
-    os.environ['os.release'] = platform.release()
-    
-    os.environ['sys.version_info'] = str(sys.version_info)
-    os.environ['sys.executable'] = sys.executable
-    os.environ['sys.path'] = str(sys.path)
-    
+def go(batch=False):
+    newenv=os.environ.copy()
+    newenv['WHATAP_VERSION'] = build.version
+    newenv['whatap.start'] = str(DateUtil.now())
+    newenv['python.uptime'] = str(DateUtil.datetime())
+    newenv['python.version'] = sys.version
+    newenv['python.tzname'] = time.tzname[0]
+    newenv['os.release'] = platform.release()
+    newenv['sys.version_info'] = str(sys.version_info)
+    newenv['sys.executable'] = sys.executable
+    newenv['sys.path'] = str(sys.path)
+
     if not batch:
         home = 'WHATAP_HOME'
         file_name = AGENT_NAME + '.pid'
@@ -357,37 +325,41 @@ def go(batch=False):
         home = 'WHATAP_HOME_BATCH'
         file_name = AGENT_NAME + '.pid.batch'
 
-    def get_pname(id):
-        p = subprocess.Popen(["ps -o cmd= {}".format(id)], stdout=subprocess.PIPE, shell=True)
-        return str(p.communicate()[0])
+    def get_pname(pid):
+        cmdlinepath = os.path.join('/proc', str(pid), 'cmdline')
+        if os.path.exists(cmdlinepath):
+            with open(cmdlinepath) as f:
+                content = f.read()
+                if content:
+                    return content.encode('utf8')
+        return ''
     pid = read_file(home, file_name)
     if pid and 'whatap_python' in get_pname(pid):
         return
     try:
-        agent_cwd = os.environ.get(home)
-        if os.path.exists(os.path.join(agent_cwd, AGENT_NAME)):
-            os.remove(os.path.join(agent_cwd, AGENT_NAME))
+        home_path= os.environ.get(home)
+        if os.path.exists(os.path.join(home_path, AGENT_NAME)):
+            os.remove(os.path.join(home_path, AGENT_NAME))
 
         source_cwd = os.path.join(os.path.join(os.path.dirname(__file__), 'agent'), platform.system().lower(),
                                   ARCH[platform.machine()])
 
 
         os.symlink(os.path.join(source_cwd, AGENT_NAME),
-                   os.path.join(agent_cwd, AGENT_NAME))
+                   os.path.join(home_path, AGENT_NAME))
 
-        os.environ['whatap.enabled'] = 'True'
+        newenv['whatap.enabled'] = 'True'
+        def preexec_function():
+            signal.signal(signal.SIGINT, signal.SIG_IGN)
         process = subprocess.Popen('./{0}'.format(AGENT_NAME),
-                                   cwd=agent_cwd)
+                                   cwd=home_path,env=newenv, preexec_fn=preexec_function)
         # Write PID file
         write_file(home, file_name, str(process.pid))
-        process.wait()
-
     except Exception as e:
         print('WHATAP: AGENT ERROR: {}'.format(e))
     else:
         print('WHATAP: AGENT UP! (process name: {})\n'.format(AGENT_NAME))
 
-
 import signal
 
 from whatap.trace.mod.application_wsgi import interceptor, start_interceptor, \
