@@ -21,7 +21,7 @@ Configuration = {
 
     "_trace_mtrace_caller_key": "x-wtap-mst",
     "_trace_mtrace_callee_key": "x-wtap-tx",
-    "_trace_mtrace_info_key": "x-wtap-inf",
+    "_trace_mtrace_info_key": "x-wtap-sp1",
     "_trace_mtrace_ip": "x-wtap-ip",
     "_trace_mtrace_caller_poid_key": "x-wtap-po",
 
@@ -192,4 +192,6 @@ Configuration = {
     "reject_event_interval": 30000,
     "master_agent_host" : "whatap-master-agent.whatap-monitoring.svc.cluster.local",
     "master_agent_port" : 6600,
+    "unix_socket_enabled":False,
+    "unix_socket":"whatap.sock",
 }
