@@ -5,6 +5,9 @@ from whatap.conf.configuration import Configuration
 
 class Configure(object):
     PCODE = 0
+    OID = 0
+    OKIND = 0
+    OKIND_NAME = os.environ.get("ENV_OKIND", "-".join(os.environ.get("POD_NAME", "").split("-")[0:-1]))
     dev = False
     net_udp_port = 6600
     last_loaded = 0
@@ -14,7 +17,7 @@ class Configure(object):
 
     @classmethod
     def init(cls, display=True):
-
+        
         cls.last_loaded = time.time()
         return cls.load(display)
 
