@@ -49,7 +49,6 @@ def intercept_receive(fn, *args, **kwargs):
         return callback
     except Exception as e:
         interceptor_step_error(e)
-        raise e
     finally:
         if ctx:
             end_interceptor(ctx=ctx)
@@ -96,8 +95,6 @@ def intercept_publish(fn, *args, **kwargs):
     finally:
         ctx.db_opening = False
 
-    return callback
-
 def instrument_kombu(module):
     def wrapper(fn):
         @trace_handler(fn)
