@@ -117,7 +117,7 @@ class TraceContextManager(object):
     @classmethod
     def end(cls, key):
         cls.local.context = None
-        cls.entry.remove(str(key))
+        cls.entry.remove(key)
 
     @classmethod
     def getTxProfile(cls, n):
